
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PictureInPicture(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-picture-in-picture'], 'items': [{'path': {'d': 'M2 10h6V4'}}, {'path': {'d': 'm2 4 6 6'}}, {'path': {'d': 'M21 10V7a2 2 0 0 0-2-2h-7'}}, {'path': {'d': 'M3 14v2a2 2 0 0 0 2 2h3'}}, {'rect': {'x': '12', 'y': '14', 'width': '10', 'height': '7', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
