
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Delete(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-delete'], 'items': [{'path': {'d': 'M10 5a2 2 0 0 0-1.344.519l-6.328 5.74a1 1 0 0 0 0 1.481l6.328 5.741A2 2 0 0 0 10 19h10a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2z'}}, {'path': {'d': 'm12 9 6 6'}}, {'path': {'d': 'm18 9-6 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
