
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Disc3(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-disc-3'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M6 12c0-1.7.7-3.2 1.8-4.2'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '2'}}, {'path': {'d': 'M18 12c0 1.7-.7 3.2-1.8 4.2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
