
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Files(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-files'], 'items': [{'path': {'d': 'M15 2h-4a2 2 0 0 0-2 2v11a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8'}}, {'path': {'d': 'M16.706 2.706A2.4 2.4 0 0 0 15 2v5a1 1 0 0 0 1 1h5a2.4 2.4 0 0 0-.706-1.706z'}}, {'path': {'d': 'M5 7a2 2 0 0 0-2 2v11a2 2 0 0 0 2 2h8a2 2 0 0 0 1.732-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
