
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileCodeCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-code-corner'], 'items': [{'path': {'d': 'M4 12.15V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2h-3.35'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'm5 16-3 3 3 3'}}, {'path': {'d': 'm9 22 3-3-3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
