
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CaseSensitive(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-case-sensitive'], 'items': [{'path': {'d': 'm2 16 4.039-9.69a.5.5 0 0 1 .923 0L11 16'}}, {'path': {'d': 'M22 9v7'}}, {'path': {'d': 'M3.304 13h6.392'}}, {'circle': {'cx': '18.5', 'cy': '12.5', 'r': '3.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
