
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Slice(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-slice'], 'items': [{'path': {'d': 'M11 16.586V19a1 1 0 0 1-1 1H2L18.37 3.63a1 1 0 1 1 3 3l-9.663 9.663a1 1 0 0 1-1.414 0L8 14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
