
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListOrdered(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-ordered'], 'items': [{'path': {'d': 'M11 5h10'}}, {'path': {'d': 'M11 12h10'}}, {'path': {'d': 'M11 19h10'}}, {'path': {'d': 'M4 4h1v5'}}, {'path': {'d': 'M4 9h2'}}, {'path': {'d': 'M6.5 20H3.4c0-1 2.6-1.925 2.6-3.5a1.5 1.5 0 0 0-2.6-1.02'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
