
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Smile(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-smile'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M8 14s1.5 2 4 2 4-2 4-2'}}, {'line': {'x1': '9', 'x2': '9.01', 'y1': '9', 'y2': '9'}}, {'line': {'x1': '15', 'x2': '15.01', 'y1': '9', 'y2': '9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
