
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareDivide(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-divide'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2', 'ry': '2'}}, {'line': {'x1': '8', 'x2': '16', 'y1': '12', 'y2': '12'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '16', 'y2': '16'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '8', 'y2': '8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
