
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Signpost(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-signpost'], 'items': [{'path': {'d': 'M12 13v8'}}, {'path': {'d': 'M12 3v3'}}, {'path': {'d': 'M18 6a2 2 0 0 1 1.387.56l2.307 2.22a1 1 0 0 1 0 1.44l-2.307 2.22A2 2 0 0 1 18 13H6a2 2 0 0 1-1.387-.56l-2.306-2.22a1 1 0 0 1 0-1.44l2.306-2.22A2 2 0 0 1 6 6z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
