
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def School(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-school'], 'items': [{'path': {'d': 'M14 21v-3a2 2 0 0 0-4 0v3'}}, {'path': {'d': 'M18 5v16'}}, {'path': {'d': 'm4 6 7.106-3.79a2 2 0 0 1 1.788 0L20 6'}}, {'path': {'d': 'm6 11-3.52 2.147a1 1 0 0 0-.48.854V19a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-5a1 1 0 0 0-.48-.853L18 11'}}, {'path': {'d': 'M6 5v16'}}, {'circle': {'cx': '12', 'cy': '9', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
