
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PanelLeftRightDashed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-panel-left-right-dashed'], 'items': [{'path': {'d': 'M15 10V9'}}, {'path': {'d': 'M15 15v-1'}}, {'path': {'d': 'M15 21v-2'}}, {'path': {'d': 'M15 5V3'}}, {'path': {'d': 'M9 10V9'}}, {'path': {'d': 'M9 15v-1'}}, {'path': {'d': 'M9 21v-2'}}, {'path': {'d': 'M9 5V3'}}, {'rect': {'x': '3', 'y': '3', 'width': '18', 'height': '18', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
