
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListStart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-start'], 'items': [{'path': {'d': 'M3 5h6'}}, {'path': {'d': 'M3 12h13'}}, {'path': {'d': 'M3 19h13'}}, {'path': {'d': 'm16 8-3-3 3-3'}}, {'path': {'d': 'M21 19V7a2 2 0 0 0-2-2h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
