
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IdCardLanyard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-id-card-lanyard'], 'items': [{'path': {'d': 'M13.5 8h-3'}}, {'path': {'d': 'm15 2-1 2h3a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h3'}}, {'path': {'d': 'M16.899 22A5 5 0 0 0 7.1 22'}}, {'path': {'d': 'm9 2 3 6'}}, {'circle': {'cx': '12', 'cy': '15', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
