
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wallet(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wallet'], 'items': [{'path': {'d': 'M19 7V4a1 1 0 0 0-1-1H5a2 2 0 0 0 0 4h15a1 1 0 0 1 1 1v4h-3a2 2 0 0 0 0 4h3a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1'}}, {'path': {'d': 'M3 5v14a2 2 0 0 0 2 2h15a1 1 0 0 0 1-1v-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
