
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Vibrate(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-vibrate'], 'items': [{'path': {'d': 'm2 8 2 2-2 2 2 2-2 2'}}, {'path': {'d': 'm22 8-2 2 2 2-2 2 2 2'}}, {'rect': {'width': '8', 'height': '14', 'x': '8', 'y': '5', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
