
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MapPinCheckInside(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-map-pin-check-inside'], 'items': [{'path': {'d': 'M20 10c0 4.993-5.539 10.193-7.399 11.799a1 1 0 0 1-1.202 0C9.539 20.193 4 14.993 4 10a8 8 0 0 1 16 0'}}, {'path': {'d': 'm9 10 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
