
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderHeart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-heart'], 'items': [{'path': {'d': 'M10.638 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v3.417'}}, {'path': {'d': 'M14.62 18.8A2.25 2.25 0 1 1 18 15.836a2.25 2.25 0 1 1 3.38 2.966l-2.626 2.856a.998.998 0 0 1-1.507 0z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
