
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Ligature(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ligature'], 'items': [{'path': {'d': 'M14 12h2v8'}}, {'path': {'d': 'M14 20h4'}}, {'path': {'d': 'M6 12h4'}}, {'path': {'d': 'M6 20h4'}}, {'path': {'d': 'M8 20V8a4 4 0 0 1 7.464-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
