
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pill(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pill'], 'items': [{'path': {'d': 'm10.5 20.5 10-10a4.95 4.95 0 1 0-7-7l-10 10a4.95 4.95 0 1 0 7 7Z'}}, {'path': {'d': 'm8.5 8.5 7 7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
