
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquaresUnite(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-squares-unite'], 'items': [{'path': {'d': 'M4 16a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v3a1 1 0 0 0 1 1h3a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H10a2 2 0 0 1-2-2v-3a1 1 0 0 0-1-1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
