
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EarthLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-earth-lock'], 'items': [{'path': {'d': 'M7 3.34V5a3 3 0 0 0 3 3'}}, {'path': {'d': 'M11 21.95V18a2 2 0 0 0-2-2 2 2 0 0 1-2-2v-1a2 2 0 0 0-2-2H2.05'}}, {'path': {'d': 'M21.54 15H17a2 2 0 0 0-2 2v4.54'}}, {'path': {'d': 'M12 2a10 10 0 1 0 9.54 13'}}, {'path': {'d': 'M20 6V4a2 2 0 1 0-4 0v2'}}, {'rect': {'width': '8', 'height': '5', 'x': '14', 'y': '6', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
