
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Luggage(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-luggage'], 'items': [{'path': {'d': 'M6 20a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2'}}, {'path': {'d': 'M8 18V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v14'}}, {'path': {'d': 'M10 20h4'}}, {'circle': {'cx': '16', 'cy': '20', 'r': '2'}}, {'circle': {'cx': '8', 'cy': '20', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
