
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ExternalLink(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-external-link'], 'items': [{'path': {'d': 'M15 3h6v6'}}, {'path': {'d': 'M10 14 21 3'}}, {'path': {'d': 'M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
