
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Watch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-watch'], 'items': [{'path': {'d': 'M12 10v2.2l1.6 1'}}, {'path': {'d': 'm16.13 7.66-.81-4.05a2 2 0 0 0-2-1.61h-2.68a2 2 0 0 0-2 1.61l-.78 4.05'}}, {'path': {'d': 'm7.88 16.36.8 4a2 2 0 0 0 2 1.61h2.72a2 2 0 0 0 2-1.61l.81-4.05'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
