
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LampWallUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp-wall-up'], 'items': [{'path': {'d': 'M19.929 9.629A1 1 0 0 1 19 11H9a1 1 0 0 1-.928-1.371l2-5A1 1 0 0 1 11 4h6a1 1 0 0 1 .928.629z'}}, {'path': {'d': 'M6 15a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H5a1 1 0 0 1-1-1v-4a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M8 18h4a2 2 0 0 0 2-2v-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
