
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Divide(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-divide'], 'items': [{'circle': {'cx': '12', 'cy': '6', 'r': '1'}}, {'line': {'x1': '5', 'x2': '19', 'y1': '12', 'y2': '12'}}, {'circle': {'cx': '12', 'cy': '18', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
