
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserRoundPen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-round-pen'], 'items': [{'path': {'d': 'M2 21a8 8 0 0 1 10.821-7.487'}}, {'path': {'d': 'M21.378 16.626a1 1 0 0 0-3.004-3.004l-4.01 4.012a2 2 0 0 0-.506.854l-.837 2.87a.5.5 0 0 0 .62.62l2.87-.837a2 2 0 0 0 .854-.506z'}}, {'circle': {'cx': '10', 'cy': '8', 'r': '5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
