
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Triangle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-triangle'], 'items': [{'path': {'d': 'M13.73 4a2 2 0 0 0-3.46 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
