
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListVideo(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-video'], 'items': [{'path': {'d': 'M21 5H3'}}, {'path': {'d': 'M10 12H3'}}, {'path': {'d': 'M10 19H3'}}, {'path': {'d': 'M15 12.003a1 1 0 0 1 1.517-.859l4.997 2.997a1 1 0 0 1 0 1.718l-4.997 2.997a1 1 0 0 1-1.517-.86z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
