
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Transgender(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-transgender'], 'items': [{'path': {'d': 'M12 16v6'}}, {'path': {'d': 'M14 20h-4'}}, {'path': {'d': 'M18 2h4v4'}}, {'path': {'d': 'm2 2 7.17 7.17'}}, {'path': {'d': 'M2 5.355V2h3.357'}}, {'path': {'d': 'm22 2-7.17 7.17'}}, {'path': {'d': 'M8 5 5 8'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
