
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lollipop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lollipop'], 'items': [{'circle': {'cx': '11', 'cy': '11', 'r': '8'}}, {'path': {'d': 'm21 21-4.3-4.3'}}, {'path': {'d': 'M11 11a2 2 0 0 0 4 0 4 4 0 0 0-8 0 6 6 0 0 0 12 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
