
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pocket(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pocket'], 'items': [{'path': {'d': 'M20 3a2 2 0 0 1 2 2v6a1 1 0 0 1-20 0V5a2 2 0 0 1 2-2z'}}, {'path': {'d': 'm8 10 4 4 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
