
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Move3d(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-3d'], 'items': [{'path': {'d': 'M5 3v16h16'}}, {'path': {'d': 'm5 19 6-6'}}, {'path': {'d': 'm2 6 3-3 3 3'}}, {'path': {'d': 'm18 16 3 3-3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
