
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hash'], 'items': [{'line': {'x1': '4', 'x2': '20', 'y1': '9', 'y2': '9'}}, {'line': {'x1': '4', 'x2': '20', 'y1': '15', 'y2': '15'}}, {'line': {'x1': '10', 'x2': '8', 'y1': '3', 'y2': '21'}}, {'line': {'x1': '16', 'x2': '14', 'y1': '3', 'y2': '21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
