
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Landmark(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-landmark'], 'items': [{'path': {'d': 'M10 18v-7'}}, {'path': {'d': 'M11.12 2.198a2 2 0 0 1 1.76.006l7.866 3.847c.476.233.31.949-.22.949H3.474c-.53 0-.695-.716-.22-.949z'}}, {'path': {'d': 'M14 18v-7'}}, {'path': {'d': 'M18 18v-7'}}, {'path': {'d': 'M3 22h18'}}, {'path': {'d': 'M6 18v-7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
