
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Keyboard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-keyboard'], 'items': [{'path': {'d': 'M10 8h.01'}}, {'path': {'d': 'M12 12h.01'}}, {'path': {'d': 'M14 8h.01'}}, {'path': {'d': 'M16 12h.01'}}, {'path': {'d': 'M18 8h.01'}}, {'path': {'d': 'M6 8h.01'}}, {'path': {'d': 'M7 16h10'}}, {'path': {'d': 'M8 12h.01'}}, {'rect': {'width': '20', 'height': '16', 'x': '2', 'y': '4', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
