
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartCandlestick(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-candlestick'], 'items': [{'path': {'d': 'M9 5v4'}}, {'rect': {'width': '4', 'height': '6', 'x': '7', 'y': '9', 'rx': '1'}}, {'path': {'d': 'M9 15v2'}}, {'path': {'d': 'M17 3v2'}}, {'rect': {'width': '4', 'height': '8', 'x': '15', 'y': '5', 'rx': '1'}}, {'path': {'d': 'M17 13v3'}}, {'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
