
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Key(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-key'], 'items': [{'path': {'d': 'm15.5 7.5 2.3 2.3a1 1 0 0 0 1.4 0l2.1-2.1a1 1 0 0 0 0-1.4L19 4'}}, {'path': {'d': 'm21 2-9.6 9.6'}}, {'circle': {'cx': '7.5', 'cy': '15.5', 'r': '5.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
