
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RotateCcwSquare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rotate-ccw-square'], 'items': [{'path': {'d': 'M20 9V7a2 2 0 0 0-2-2h-6'}}, {'path': {'d': 'm15 2-3 3 3 3'}}, {'path': {'d': 'M20 13v5a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
