
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TvMinimalPlay(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tv-minimal-play'], 'items': [{'path': {'d': 'M15.033 9.44a.647.647 0 0 1 0 1.12l-4.065 2.352a.645.645 0 0 1-.968-.56V7.648a.645.645 0 0 1 .967-.56z'}}, {'path': {'d': 'M7 21h10'}}, {'rect': {'width': '20', 'height': '14', 'x': '2', 'y': '3', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
