
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WavesArrowUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-waves-arrow-up'], 'items': [{'path': {'d': 'M12 2v8'}}, {'path': {'d': 'M2 15c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1'}}, {'path': {'d': 'M2 21c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1'}}, {'path': {'d': 'm8 6 4-4 4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
