
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wand(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wand'], 'items': [{'path': {'d': 'M15 4V2'}}, {'path': {'d': 'M15 16v-2'}}, {'path': {'d': 'M8 9h2'}}, {'path': {'d': 'M20 9h2'}}, {'path': {'d': 'M17.8 11.8 19 13'}}, {'path': {'d': 'M15 9h.01'}}, {'path': {'d': 'M17.8 6.2 19 5'}}, {'path': {'d': 'm3 21 9-9'}}, {'path': {'d': 'M12.2 6.2 11 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
