
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HousePlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-house-plus'], 'items': [{'path': {'d': 'M12.35 21H5a2 2 0 0 1-2-2v-9a2 2 0 0 1 .71-1.53l7-6a2 2 0 0 1 2.58 0l7 6A2 2 0 0 1 21 10v2.35'}}, {'path': {'d': 'M14.8 12.4A1 1 0 0 0 14 12h-4a1 1 0 0 0-1 1v8'}}, {'path': {'d': 'M15 18h6'}}, {'path': {'d': 'M18 15v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
