
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Strikethrough(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-strikethrough'], 'items': [{'path': {'d': 'M16 4H9a3 3 0 0 0-2.83 4'}}, {'path': {'d': 'M14 12a4 4 0 0 1 0 8H6'}}, {'line': {'x1': '4', 'x2': '20', 'y1': '12', 'y2': '12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
