
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CaseUpper(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-case-upper'], 'items': [{'path': {'d': 'M15 11h4.5a1 1 0 0 1 0 5h-4a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h3a1 1 0 0 1 0 5'}}, {'path': {'d': 'm2 16 4.039-9.69a.5.5 0 0 1 .923 0L11 16'}}, {'path': {'d': 'M3.304 13h6.392'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
