
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Images(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-images'], 'items': [{'path': {'d': 'm22 11-1.296-1.296a2.4 2.4 0 0 0-3.408 0L11 16'}}, {'path': {'d': 'M4 8a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2'}}, {'circle': {'cx': '13', 'cy': '7', 'r': '1', 'fill': 'currentColor'}}, {'rect': {'x': '8', 'y': '2', 'width': '14', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
