
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DoorOpen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-door-open'], 'items': [{'path': {'d': 'M11 20H2'}}, {'path': {'d': 'M11 4.562v16.157a1 1 0 0 0 1.242.97L19 20V5.562a2 2 0 0 0-1.515-1.94l-4-1A2 2 0 0 0 11 4.561z'}}, {'path': {'d': 'M11 4H8a2 2 0 0 0-2 2v14'}}, {'path': {'d': 'M14 12h.01'}}, {'path': {'d': 'M22 20h-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
