
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListIndentIncrease(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-indent-increase'], 'items': [{'path': {'d': 'M21 5H11'}}, {'path': {'d': 'M21 12H11'}}, {'path': {'d': 'M21 19H11'}}, {'path': {'d': 'm3 8 4 4-4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
