
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def VideoOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-video-off'], 'items': [{'path': {'d': 'M10.66 6H14a2 2 0 0 1 2 2v2.5l5.248-3.062A.5.5 0 0 1 22 7.87v8.196'}}, {'path': {'d': 'M16 16a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h2'}}, {'path': {'d': 'm2 2 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
