
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Signature(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-signature'], 'items': [{'path': {'d': 'm21 17-2.156-1.868A.5.5 0 0 0 18 15.5v.5a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1c0-2.545-3.991-3.97-8.5-4a1 1 0 0 0 0 5c4.153 0 4.745-11.295 5.708-13.5a2.5 2.5 0 1 1 3.31 3.284'}}, {'path': {'d': 'M3 21h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
