
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LampWallDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp-wall-down'], 'items': [{'path': {'d': 'M19.929 18.629A1 1 0 0 1 19 20H9a1 1 0 0 1-.928-1.371l2-5A1 1 0 0 1 11 13h6a1 1 0 0 1 .928.629z'}}, {'path': {'d': 'M6 3a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H5a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M8 6h4a2 2 0 0 1 2 2v5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
