
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bandage(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bandage'], 'items': [{'path': {'d': 'M10 10.01h.01'}}, {'path': {'d': 'M10 14.01h.01'}}, {'path': {'d': 'M14 10.01h.01'}}, {'path': {'d': 'M14 14.01h.01'}}, {'path': {'d': 'M18 6v11.5'}}, {'path': {'d': 'M6 6v12'}}, {'rect': {'x': '2', 'y': '6', 'width': '20', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
