
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RotateCcwKey(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rotate-ccw-key'], 'items': [{'path': {'d': 'm14.5 9.5 1 1'}}, {'path': {'d': 'm15.5 8.5-4 4'}}, {'path': {'d': 'M3 12a9 9 0 1 0 9-9 9.74 9.74 0 0 0-6.74 2.74L3 8'}}, {'path': {'d': 'M3 3v5h5'}}, {'circle': {'cx': '10', 'cy': '14', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
