
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Youtube(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-youtube'], 'items': [{'path': {'d': 'M2.5 17a24.12 24.12 0 0 1 0-10 2 2 0 0 1 1.4-1.4 49.56 49.56 0 0 1 16.2 0A2 2 0 0 1 21.5 7a24.12 24.12 0 0 1 0 10 2 2 0 0 1-1.4 1.4 49.55 49.55 0 0 1-16.2 0A2 2 0 0 1 2.5 17'}}, {'path': {'d': 'm10 15 5-3-5-3z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
