
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Copy(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-copy'], 'items': [{'rect': {'width': '14', 'height': '14', 'x': '8', 'y': '8', 'rx': '2', 'ry': '2'}}, {'path': {'d': 'M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
