
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lamp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp'], 'items': [{'path': {'d': 'M12 12v6'}}, {'path': {'d': 'M4.077 10.615A1 1 0 0 0 5 12h14a1 1 0 0 0 .923-1.385l-3.077-7.384A2 2 0 0 0 15 2H9a2 2 0 0 0-1.846 1.23Z'}}, {'path': {'d': 'M8 20a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1H9a1 1 0 0 1-1-1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
