
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CookingPot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cooking-pot'], 'items': [{'path': {'d': 'M2 12h20'}}, {'path': {'d': 'M20 12v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-8'}}, {'path': {'d': 'm4 8 16-4'}}, {'path': {'d': 'm8.86 6.78-.45-1.81a2 2 0 0 1 1.45-2.43l1.94-.48a2 2 0 0 1 2.43 1.46l.45 1.8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
