
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def VenetianMask(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-venetian-mask'], 'items': [{'path': {'d': 'M18 11c-1.5 0-2.5.5-3 2'}}, {'path': {'d': 'M4 6a2 2 0 0 0-2 2v4a5 5 0 0 0 5 5 8 8 0 0 1 5 2 8 8 0 0 1 5-2 5 5 0 0 0 5-5V8a2 2 0 0 0-2-2h-3a8 8 0 0 0-5 2 8 8 0 0 0-5-2z'}}, {'path': {'d': 'M6 11c1.5 0 2.5.5 3 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
