
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Backpack(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-backpack'], 'items': [{'path': {'d': 'M4 10a4 4 0 0 1 4-4h8a4 4 0 0 1 4 4v10a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2z'}}, {'path': {'d': 'M8 10h8'}}, {'path': {'d': 'M8 18h8'}}, {'path': {'d': 'M8 22v-6a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v6'}}, {'path': {'d': 'M9 6V4a2 2 0 0 1 2-2h2a2 2 0 0 1 2 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
