
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Laptop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-laptop'], 'items': [{'path': {'d': 'M18 5a2 2 0 0 1 2 2v8.526a2 2 0 0 0 .212.897l1.068 2.127a1 1 0 0 1-.9 1.45H3.62a1 1 0 0 1-.9-1.45l1.068-2.127A2 2 0 0 0 4 15.526V7a2 2 0 0 1 2-2z'}}, {'path': {'d': 'M20.054 15.987H3.946'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
