
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorCloud(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-cloud'], 'items': [{'path': {'d': 'M11 13a3 3 0 1 1 2.83-4H14a2 2 0 0 1 0 4z'}}, {'path': {'d': 'M12 17v4'}}, {'path': {'d': 'M8 21h8'}}, {'rect': {'x': '2', 'y': '3', 'width': '20', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
