
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquarePen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-pen'], 'items': [{'path': {'d': 'M12 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7'}}, {'path': {'d': 'M18.375 2.625a1 1 0 0 1 3 3l-9.013 9.014a2 2 0 0 1-.853.505l-2.873.84a.5.5 0 0 1-.62-.62l.84-2.873a2 2 0 0 1 .506-.852z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
